# generated by datamodel-codegen:
#   filename:  v2-normal.json
#   timestamp: 2023-06-09T14:34:47+00:00

from __future__ import annotations

from typing import Any, Dict, List

from pydantic import BaseModel


class Metadata(BaseModel):
    apiVersion: str
    endpointPrefix: str
    jsonVersion: str
    protocol: str
    serviceAbbreviation: str
    serviceFullName: str
    serviceId: str
    signatureVersion: str
    targetPrefix: str
    uid: str


class Http(BaseModel):
    method: str
    requestUri: str


class Input(BaseModel):
    shape: str


class Output(BaseModel):
    shape: str


class Error(BaseModel):
    shape: str


class CreateActivity(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str
    idempotent: bool


class CreateStateMachine(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str
    idempotent: bool


class DeleteActivity(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class DeleteStateMachine(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class DescribeActivity(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class DescribeExecution(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class DescribeMapRun(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class DescribeStateMachine(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class DescribeStateMachineForExecution(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class GetActivityTask(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class GetExecutionHistory(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class ListActivities(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class ListExecutions(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class ListMapRuns(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class ListStateMachines(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class ListTagsForResource(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class SendTaskFailure(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class SendTaskHeartbeat(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class SendTaskSuccess(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class StartExecution(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str
    idempotent: bool


class Endpoint(BaseModel):
    hostPrefix: str


class StartSyncExecution(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str
    endpoint: Endpoint


class StopExecution(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class TagResource(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class UntagResource(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class UpdateMapRun(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str


class UpdateStateMachine(BaseModel):
    name: str
    http: Http
    input: Input
    output: Output
    errors: List[Error]
    documentation: str
    idempotent: bool


class Operations(BaseModel):
    CreateActivity: CreateActivity
    CreateStateMachine: CreateStateMachine
    DeleteActivity: DeleteActivity
    DeleteStateMachine: DeleteStateMachine
    DescribeActivity: DescribeActivity
    DescribeExecution: DescribeExecution
    DescribeMapRun: DescribeMapRun
    DescribeStateMachine: DescribeStateMachine
    DescribeStateMachineForExecution: DescribeStateMachineForExecution
    GetActivityTask: GetActivityTask
    GetExecutionHistory: GetExecutionHistory
    ListActivities: ListActivities
    ListExecutions: ListExecutions
    ListMapRuns: ListMapRuns
    ListStateMachines: ListStateMachines
    ListTagsForResource: ListTagsForResource
    SendTaskFailure: SendTaskFailure
    SendTaskHeartbeat: SendTaskHeartbeat
    SendTaskSuccess: SendTaskSuccess
    StartExecution: StartExecution
    StartSyncExecution: StartSyncExecution
    StopExecution: StopExecution
    TagResource: TagResource
    UntagResource: UntagResource
    UpdateMapRun: UpdateMapRun
    UpdateStateMachine: UpdateStateMachine


class Error26(BaseModel):
    shape: str
    documentation: str


class Cause(BaseModel):
    shape: str
    documentation: str


class Members(BaseModel):
    error: Error26
    cause: Cause


class ActivityFailedEventDetails(BaseModel):
    type: str
    members: Members
    documentation: str


class Member(BaseModel):
    shape: str


class ActivityList(BaseModel):
    type: str
    member: Member


class ActivityArn(BaseModel):
    shape: str
    documentation: str


class Name(BaseModel):
    shape: str
    documentation: str


class CreationDate(BaseModel):
    shape: str
    documentation: str


class Members1(BaseModel):
    activityArn: ActivityArn
    name: Name
    creationDate: CreationDate


class ActivityListItem(BaseModel):
    type: str
    required: List[str]
    members: Members1
    documentation: str


class Members2(BaseModel):
    error: Error26
    cause: Cause


class ActivityScheduleFailedEventDetails(BaseModel):
    type: str
    members: Members2
    documentation: str


class Resource(BaseModel):
    shape: str
    documentation: str


class Input26(BaseModel):
    shape: str
    documentation: str


class InputDetails(BaseModel):
    shape: str
    documentation: str


class TimeoutInSeconds(BaseModel):
    shape: str
    documentation: str
    box: bool


class HeartbeatInSeconds(BaseModel):
    shape: str
    documentation: str
    box: bool


class Members3(BaseModel):
    resource: Resource
    input: Input26
    inputDetails: InputDetails
    timeoutInSeconds: TimeoutInSeconds
    heartbeatInSeconds: HeartbeatInSeconds


class ActivityScheduledEventDetails(BaseModel):
    type: str
    required: List[str]
    members: Members3
    documentation: str


class WorkerName(BaseModel):
    shape: str
    documentation: str


class Members4(BaseModel):
    workerName: WorkerName


class ActivityStartedEventDetails(BaseModel):
    type: str
    members: Members4
    documentation: str


class Output26(BaseModel):
    shape: str
    documentation: str


class OutputDetails(BaseModel):
    shape: str
    documentation: str


class Members5(BaseModel):
    output: Output26
    outputDetails: OutputDetails


class ActivitySucceededEventDetails(BaseModel):
    type: str
    members: Members5
    documentation: str


class Members6(BaseModel):
    error: Error26
    cause: Cause


class ActivityTimedOutEventDetails(BaseModel):
    type: str
    members: Members6
    documentation: str


class Arn(BaseModel):
    type: str
    max: int
    min: int


class BilledDuration(BaseModel):
    type: str
    min: int


class BilledMemoryUsed(BaseModel):
    type: str
    min: int


class BilledMemoryUsedInMB(BaseModel):
    shape: str
    documentation: str


class BilledDurationInMilliseconds(BaseModel):
    shape: str
    documentation: str


class Members7(BaseModel):
    billedMemoryUsedInMB: BilledMemoryUsedInMB
    billedDurationInMilliseconds: BilledDurationInMilliseconds


class BillingDetails(BaseModel):
    type: str
    members: Members7
    documentation: str


class Included(BaseModel):
    shape: str
    documentation: str


class Members8(BaseModel):
    included: Included


class CloudWatchEventsExecutionDataDetails(BaseModel):
    type: str
    members: Members8
    documentation: str


class LogGroupArn(BaseModel):
    shape: str
    documentation: str


class Members9(BaseModel):
    logGroupArn: LogGroupArn


class CloudWatchLogsLogGroup(BaseModel):
    type: str
    members: Members9
    documentation: str


class ConnectorParameters(BaseModel):
    type: str
    max: int
    min: int
    sensitive: bool


class Tags(BaseModel):
    shape: str
    documentation: str


class Members10(BaseModel):
    name: Name
    tags: Tags


class CreateActivityInput(BaseModel):
    type: str
    required: List[str]
    members: Members10


class Members11(BaseModel):
    activityArn: ActivityArn
    creationDate: CreationDate


class CreateActivityOutput(BaseModel):
    type: str
    required: List[str]
    members: Members11


class Definition(BaseModel):
    shape: str
    documentation: str


class RoleArn(BaseModel):
    shape: str
    documentation: str


class Type(BaseModel):
    shape: str
    documentation: str


class LoggingConfiguration(BaseModel):
    shape: str
    documentation: str


class TracingConfiguration(BaseModel):
    shape: str
    documentation: str


class Members12(BaseModel):
    name: Name
    definition: Definition
    roleArn: RoleArn
    type: Type
    loggingConfiguration: LoggingConfiguration
    tags: Tags
    tracingConfiguration: TracingConfiguration


class CreateStateMachineInput(BaseModel):
    type: str
    required: List[str]
    members: Members12


class StateMachineArn(BaseModel):
    shape: str
    documentation: str


class Members13(BaseModel):
    stateMachineArn: StateMachineArn
    creationDate: CreationDate


class CreateStateMachineOutput(BaseModel):
    type: str
    required: List[str]
    members: Members13


class Definition1(BaseModel):
    type: str
    max: int
    min: int
    sensitive: bool


class Members14(BaseModel):
    activityArn: ActivityArn


class DeleteActivityInput(BaseModel):
    type: str
    required: List[str]
    members: Members14


class DeleteActivityOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class Members15(BaseModel):
    stateMachineArn: StateMachineArn


class DeleteStateMachineInput(BaseModel):
    type: str
    required: List[str]
    members: Members15


class DeleteStateMachineOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class Members16(BaseModel):
    activityArn: ActivityArn


class DescribeActivityInput(BaseModel):
    type: str
    required: List[str]
    members: Members16


class Members17(BaseModel):
    activityArn: ActivityArn
    name: Name
    creationDate: CreationDate


class DescribeActivityOutput(BaseModel):
    type: str
    required: List[str]
    members: Members17


class ExecutionArn(BaseModel):
    shape: str
    documentation: str


class Members18(BaseModel):
    executionArn: ExecutionArn


class DescribeExecutionInput(BaseModel):
    type: str
    required: List[str]
    members: Members18


class Status(BaseModel):
    shape: str
    documentation: str


class StartDate(BaseModel):
    shape: str
    documentation: str


class StopDate(BaseModel):
    shape: str
    documentation: str


class InputDetails1(BaseModel):
    shape: str


class OutputDetails1(BaseModel):
    shape: str


class TraceHeader(BaseModel):
    shape: str
    documentation: str


class MapRunArn(BaseModel):
    shape: str
    documentation: str


class Members19(BaseModel):
    executionArn: ExecutionArn
    stateMachineArn: StateMachineArn
    name: Name
    status: Status
    startDate: StartDate
    stopDate: StopDate
    input: Input26
    inputDetails: InputDetails1
    output: Output26
    outputDetails: OutputDetails1
    traceHeader: TraceHeader
    mapRunArn: MapRunArn
    error: Error26
    cause: Cause


class DescribeExecutionOutput(BaseModel):
    type: str
    required: List[str]
    members: Members19


class Members20(BaseModel):
    mapRunArn: MapRunArn


class DescribeMapRunInput(BaseModel):
    type: str
    required: List[str]
    members: Members20


class MaxConcurrency(BaseModel):
    shape: str
    documentation: str


class ToleratedFailurePercentage(BaseModel):
    shape: str
    documentation: str


class ToleratedFailureCount(BaseModel):
    shape: str
    documentation: str


class ItemCounts(BaseModel):
    shape: str
    documentation: str


class ExecutionCounts(BaseModel):
    shape: str
    documentation: str


class Members21(BaseModel):
    mapRunArn: MapRunArn
    executionArn: ExecutionArn
    status: Status
    startDate: StartDate
    stopDate: StopDate
    maxConcurrency: MaxConcurrency
    toleratedFailurePercentage: ToleratedFailurePercentage
    toleratedFailureCount: ToleratedFailureCount
    itemCounts: ItemCounts
    executionCounts: ExecutionCounts


class DescribeMapRunOutput(BaseModel):
    type: str
    required: List[str]
    members: Members21


class Members22(BaseModel):
    executionArn: ExecutionArn


class DescribeStateMachineForExecutionInput(BaseModel):
    type: str
    required: List[str]
    members: Members22


class Definition2(BaseModel):
    shape: str
    documentation: str


class UpdateDate(BaseModel):
    shape: str
    documentation: str


class LoggingConfiguration1(BaseModel):
    shape: str


class Label(BaseModel):
    shape: str
    documentation: str


class Members23(BaseModel):
    stateMachineArn: StateMachineArn
    name: Name
    definition: Definition2
    roleArn: RoleArn
    updateDate: UpdateDate
    loggingConfiguration: LoggingConfiguration1
    tracingConfiguration: TracingConfiguration
    mapRunArn: MapRunArn
    label: Label


class DescribeStateMachineForExecutionOutput(BaseModel):
    type: str
    required: List[str]
    members: Members23


class Members24(BaseModel):
    stateMachineArn: StateMachineArn


class DescribeStateMachineInput(BaseModel):
    type: str
    required: List[str]
    members: Members24


class Members25(BaseModel):
    stateMachineArn: StateMachineArn
    name: Name
    status: Status
    definition: Definition2
    roleArn: RoleArn
    type: Type
    creationDate: CreationDate
    loggingConfiguration: LoggingConfiguration1
    tracingConfiguration: TracingConfiguration
    label: Label


class DescribeStateMachineOutput(BaseModel):
    type: str
    required: List[str]
    members: Members25


class Enabled(BaseModel):
    type: str


class EventId(BaseModel):
    type: str


class Members26(BaseModel):
    error: Error26
    cause: Cause


class ExecutionAbortedEventDetails(BaseModel):
    type: str
    members: Members26
    documentation: str


class Members27(BaseModel):
    error: Error26
    cause: Cause


class ExecutionFailedEventDetails(BaseModel):
    type: str
    members: Members27
    documentation: str


class ExecutionList(BaseModel):
    type: str
    member: Member


class ItemCount(BaseModel):
    shape: str
    documentation: str
    box: bool


class Members28(BaseModel):
    executionArn: ExecutionArn
    stateMachineArn: StateMachineArn
    name: Name
    status: Status
    startDate: StartDate
    stopDate: StopDate
    mapRunArn: MapRunArn
    itemCount: ItemCount


class ExecutionListItem(BaseModel):
    type: str
    required: List[str]
    members: Members28
    documentation: str


class InputDetails2(BaseModel):
    shape: str
    documentation: str


class Members29(BaseModel):
    input: Input26
    inputDetails: InputDetails2
    roleArn: RoleArn


class ExecutionStartedEventDetails(BaseModel):
    type: str
    members: Members29
    documentation: str


class ExecutionStatus(BaseModel):
    type: str
    enum: List[str]


class OutputDetails2(BaseModel):
    shape: str
    documentation: str


class Members30(BaseModel):
    output: Output26
    outputDetails: OutputDetails2


class ExecutionSucceededEventDetails(BaseModel):
    type: str
    members: Members30
    documentation: str


class Members31(BaseModel):
    error: Error26
    cause: Cause


class ExecutionTimedOutEventDetails(BaseModel):
    type: str
    members: Members31
    documentation: str


class Members32(BaseModel):
    activityArn: ActivityArn
    workerName: WorkerName


class GetActivityTaskInput(BaseModel):
    type: str
    required: List[str]
    members: Members32


class TaskToken(BaseModel):
    shape: str
    documentation: str


class Members33(BaseModel):
    taskToken: TaskToken
    input: Input26


class GetActivityTaskOutput(BaseModel):
    type: str
    members: Members33


class MaxResults(BaseModel):
    shape: str
    documentation: str


class ReverseOrder(BaseModel):
    shape: str
    documentation: str


class NextToken(BaseModel):
    shape: str
    documentation: str


class IncludeExecutionData(BaseModel):
    shape: str
    documentation: str


class Members34(BaseModel):
    executionArn: ExecutionArn
    maxResults: MaxResults
    reverseOrder: ReverseOrder
    nextToken: NextToken
    includeExecutionData: IncludeExecutionData


class GetExecutionHistoryInput(BaseModel):
    type: str
    required: List[str]
    members: Members34


class Events(BaseModel):
    shape: str
    documentation: str


class Members35(BaseModel):
    events: Events
    nextToken: NextToken


class GetExecutionHistoryOutput(BaseModel):
    type: str
    required: List[str]
    members: Members35


class Timestamp(BaseModel):
    shape: str
    documentation: str


class Id(BaseModel):
    shape: str
    documentation: str


class PreviousEventId(BaseModel):
    shape: str
    documentation: str


class ActivityFailedEventDetails1(BaseModel):
    shape: str


class ActivityScheduleFailedEventDetails1(BaseModel):
    shape: str
    documentation: str


class ActivityScheduledEventDetails1(BaseModel):
    shape: str


class ActivityStartedEventDetails1(BaseModel):
    shape: str


class ActivitySucceededEventDetails1(BaseModel):
    shape: str


class ActivityTimedOutEventDetails1(BaseModel):
    shape: str


class TaskFailedEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskScheduledEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskStartFailedEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskStartedEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskSubmitFailedEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskSubmittedEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskSucceededEventDetails(BaseModel):
    shape: str
    documentation: str


class TaskTimedOutEventDetails(BaseModel):
    shape: str
    documentation: str


class ExecutionFailedEventDetails1(BaseModel):
    shape: str


class ExecutionStartedEventDetails1(BaseModel):
    shape: str


class ExecutionSucceededEventDetails1(BaseModel):
    shape: str


class ExecutionAbortedEventDetails1(BaseModel):
    shape: str


class ExecutionTimedOutEventDetails1(BaseModel):
    shape: str


class MapStateStartedEventDetails(BaseModel):
    shape: str
    documentation: str


class MapIterationStartedEventDetails(BaseModel):
    shape: str
    documentation: str


class MapIterationSucceededEventDetails(BaseModel):
    shape: str
    documentation: str


class MapIterationFailedEventDetails(BaseModel):
    shape: str
    documentation: str


class MapIterationAbortedEventDetails(BaseModel):
    shape: str
    documentation: str


class LambdaFunctionFailedEventDetails(BaseModel):
    shape: str


class LambdaFunctionScheduleFailedEventDetails(BaseModel):
    shape: str


class LambdaFunctionScheduledEventDetails(BaseModel):
    shape: str


class LambdaFunctionStartFailedEventDetails(BaseModel):
    shape: str
    documentation: str


class LambdaFunctionSucceededEventDetails(BaseModel):
    shape: str
    documentation: str


class LambdaFunctionTimedOutEventDetails(BaseModel):
    shape: str


class StateEnteredEventDetails(BaseModel):
    shape: str


class StateExitedEventDetails(BaseModel):
    shape: str


class MapRunStartedEventDetails(BaseModel):
    shape: str
    documentation: str


class MapRunFailedEventDetails(BaseModel):
    shape: str
    documentation: str


class Members36(BaseModel):
    timestamp: Timestamp
    type: Type
    id: Id
    previousEventId: PreviousEventId
    activityFailedEventDetails: ActivityFailedEventDetails1
    activityScheduleFailedEventDetails: ActivityScheduleFailedEventDetails1
    activityScheduledEventDetails: ActivityScheduledEventDetails1
    activityStartedEventDetails: ActivityStartedEventDetails1
    activitySucceededEventDetails: ActivitySucceededEventDetails1
    activityTimedOutEventDetails: ActivityTimedOutEventDetails1
    taskFailedEventDetails: TaskFailedEventDetails
    taskScheduledEventDetails: TaskScheduledEventDetails
    taskStartFailedEventDetails: TaskStartFailedEventDetails
    taskStartedEventDetails: TaskStartedEventDetails
    taskSubmitFailedEventDetails: TaskSubmitFailedEventDetails
    taskSubmittedEventDetails: TaskSubmittedEventDetails
    taskSucceededEventDetails: TaskSucceededEventDetails
    taskTimedOutEventDetails: TaskTimedOutEventDetails
    executionFailedEventDetails: ExecutionFailedEventDetails1
    executionStartedEventDetails: ExecutionStartedEventDetails1
    executionSucceededEventDetails: ExecutionSucceededEventDetails1
    executionAbortedEventDetails: ExecutionAbortedEventDetails1
    executionTimedOutEventDetails: ExecutionTimedOutEventDetails1
    mapStateStartedEventDetails: MapStateStartedEventDetails
    mapIterationStartedEventDetails: MapIterationStartedEventDetails
    mapIterationSucceededEventDetails: MapIterationSucceededEventDetails
    mapIterationFailedEventDetails: MapIterationFailedEventDetails
    mapIterationAbortedEventDetails: MapIterationAbortedEventDetails
    lambdaFunctionFailedEventDetails: LambdaFunctionFailedEventDetails
    lambdaFunctionScheduleFailedEventDetails: LambdaFunctionScheduleFailedEventDetails
    lambdaFunctionScheduledEventDetails: LambdaFunctionScheduledEventDetails
    lambdaFunctionStartFailedEventDetails: LambdaFunctionStartFailedEventDetails
    lambdaFunctionSucceededEventDetails: LambdaFunctionSucceededEventDetails
    lambdaFunctionTimedOutEventDetails: LambdaFunctionTimedOutEventDetails
    stateEnteredEventDetails: StateEnteredEventDetails
    stateExitedEventDetails: StateExitedEventDetails
    mapRunStartedEventDetails: MapRunStartedEventDetails
    mapRunFailedEventDetails: MapRunFailedEventDetails


class HistoryEvent(BaseModel):
    type: str
    required: List[str]
    members: Members36
    documentation: str


class Truncated(BaseModel):
    shape: str
    documentation: str


class Members37(BaseModel):
    truncated: Truncated


class HistoryEventExecutionDataDetails(BaseModel):
    type: str
    members: Members37
    documentation: str


class HistoryEventList(BaseModel):
    type: str
    member: Member
    documentation: str


class HistoryEventType(BaseModel):
    type: str
    enum: List[str]


class Identity(BaseModel):
    type: str
    max: int


class IncludeExecutionData1(BaseModel):
    type: str


class IncludeExecutionDataGetExecutionHistory(BaseModel):
    type: str
    box: bool


class Members38(BaseModel):
    error: Error26
    cause: Cause


class LambdaFunctionFailedEventDetails1(BaseModel):
    type: str
    members: Members38
    documentation: str


class Members39(BaseModel):
    error: Error26
    cause: Cause


class LambdaFunctionScheduleFailedEventDetails1(BaseModel):
    type: str
    members: Members39
    documentation: str


class TaskCredentials(BaseModel):
    shape: str
    documentation: str


class Members40(BaseModel):
    resource: Resource
    input: Input26
    inputDetails: InputDetails2
    timeoutInSeconds: TimeoutInSeconds
    taskCredentials: TaskCredentials


class LambdaFunctionScheduledEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members40
    documentation: str


class Members41(BaseModel):
    error: Error26
    cause: Cause


class LambdaFunctionStartFailedEventDetails1(BaseModel):
    type: str
    members: Members41
    documentation: str


class Members42(BaseModel):
    output: Output26
    outputDetails: OutputDetails2


class LambdaFunctionSucceededEventDetails1(BaseModel):
    type: str
    members: Members42
    documentation: str


class Members43(BaseModel):
    error: Error26
    cause: Cause


class LambdaFunctionTimedOutEventDetails1(BaseModel):
    type: str
    members: Members43
    documentation: str


class Members44(BaseModel):
    maxResults: MaxResults
    nextToken: NextToken


class ListActivitiesInput(BaseModel):
    type: str
    members: Members44


class Activities(BaseModel):
    shape: str
    documentation: str


class Members45(BaseModel):
    activities: Activities
    nextToken: NextToken


class ListActivitiesOutput(BaseModel):
    type: str
    required: List[str]
    members: Members45


class StatusFilter(BaseModel):
    shape: str
    documentation: str


class Members46(BaseModel):
    stateMachineArn: StateMachineArn
    statusFilter: StatusFilter
    maxResults: MaxResults
    nextToken: NextToken
    mapRunArn: MapRunArn


class ListExecutionsInput(BaseModel):
    type: str
    members: Members46


class Executions(BaseModel):
    shape: str
    documentation: str


class Members47(BaseModel):
    executions: Executions
    nextToken: NextToken


class ListExecutionsOutput(BaseModel):
    type: str
    required: List[str]
    members: Members47


class ListExecutionsPageToken(BaseModel):
    type: str
    max: int
    min: int


class Members48(BaseModel):
    executionArn: ExecutionArn
    maxResults: MaxResults
    nextToken: NextToken


class ListMapRunsInput(BaseModel):
    type: str
    required: List[str]
    members: Members48


class MapRuns(BaseModel):
    shape: str
    documentation: str


class Members49(BaseModel):
    mapRuns: MapRuns
    nextToken: NextToken


class ListMapRunsOutput(BaseModel):
    type: str
    required: List[str]
    members: Members49


class Members50(BaseModel):
    maxResults: MaxResults
    nextToken: NextToken


class ListStateMachinesInput(BaseModel):
    type: str
    members: Members50


class StateMachines(BaseModel):
    shape: str


class Members51(BaseModel):
    stateMachines: StateMachines
    nextToken: NextToken


class ListStateMachinesOutput(BaseModel):
    type: str
    required: List[str]
    members: Members51


class ResourceArn(BaseModel):
    shape: str
    documentation: str


class Members52(BaseModel):
    resourceArn: ResourceArn


class ListTagsForResourceInput(BaseModel):
    type: str
    required: List[str]
    members: Members52


class Members53(BaseModel):
    tags: Tags


class ListTagsForResourceOutput(BaseModel):
    type: str
    members: Members53


class CloudWatchLogsLogGroup1(BaseModel):
    shape: str
    documentation: str


class Members54(BaseModel):
    cloudWatchLogsLogGroup: CloudWatchLogsLogGroup1


class LogDestination(BaseModel):
    type: str
    members: Members54
    documentation: str


class LogDestinationList(BaseModel):
    type: str
    member: Member


class LogLevel(BaseModel):
    type: str
    enum: List[str]


class Level(BaseModel):
    shape: str
    documentation: str


class IncludeExecutionData2(BaseModel):
    shape: str
    documentation: str


class Destinations(BaseModel):
    shape: str
    documentation: str


class Members55(BaseModel):
    level: Level
    includeExecutionData: IncludeExecutionData2
    destinations: Destinations


class LoggingConfiguration3(BaseModel):
    type: str
    members: Members55
    documentation: str


class LongArn(BaseModel):
    type: str
    max: int
    min: int


class Index(BaseModel):
    shape: str
    documentation: str


class Members56(BaseModel):
    name: Name
    index: Index


class MapIterationEventDetails(BaseModel):
    type: str
    members: Members56
    documentation: str


class Pending(BaseModel):
    shape: str
    documentation: str


class Running(BaseModel):
    shape: str
    documentation: str


class Succeeded(BaseModel):
    shape: str
    documentation: str


class Failed(BaseModel):
    shape: str
    documentation: str


class TimedOut(BaseModel):
    shape: str
    documentation: str


class Aborted(BaseModel):
    shape: str
    documentation: str


class Total(BaseModel):
    shape: str
    documentation: str


class ResultsWritten(BaseModel):
    shape: str
    documentation: str


class Members57(BaseModel):
    pending: Pending
    running: Running
    succeeded: Succeeded
    failed: Failed
    timedOut: TimedOut
    aborted: Aborted
    total: Total
    resultsWritten: ResultsWritten


class MapRunExecutionCounts(BaseModel):
    type: str
    required: List[str]
    members: Members57
    documentation: str


class Members58(BaseModel):
    error: Error26
    cause: Cause


class MapRunFailedEventDetails1(BaseModel):
    type: str
    members: Members58
    documentation: str


class Members59(BaseModel):
    pending: Pending
    running: Running
    succeeded: Succeeded
    failed: Failed
    timedOut: TimedOut
    aborted: Aborted
    total: Total
    resultsWritten: ResultsWritten


class MapRunItemCounts(BaseModel):
    type: str
    required: List[str]
    members: Members59
    documentation: str


class MapRunLabel(BaseModel):
    type: str


class MapRunList(BaseModel):
    type: str
    member: Member


class Members60(BaseModel):
    executionArn: ExecutionArn
    mapRunArn: MapRunArn
    stateMachineArn: StateMachineArn
    startDate: StartDate
    stopDate: StopDate


class MapRunListItem(BaseModel):
    type: str
    required: List[str]
    members: Members60
    documentation: str


class Members61(BaseModel):
    mapRunArn: MapRunArn


class MapRunStartedEventDetails1(BaseModel):
    type: str
    members: Members61
    documentation: str


class MapRunStatus(BaseModel):
    type: str
    enum: List[str]


class Length(BaseModel):
    shape: str
    documentation: str


class Members62(BaseModel):
    length: Length


class MapStateStartedEventDetails1(BaseModel):
    type: str
    members: Members62
    documentation: str


class MaxConcurrency1(BaseModel):
    type: str
    min: int


class Name9(BaseModel):
    type: str
    max: int
    min: int


class PageSize(BaseModel):
    type: str
    max: int
    min: int


class PageToken(BaseModel):
    type: str
    max: int
    min: int


class ReverseOrder1(BaseModel):
    type: str


class Members63(BaseModel):
    taskToken: TaskToken
    error: Error26
    cause: Cause


class SendTaskFailureInput(BaseModel):
    type: str
    required: List[str]
    members: Members63


class SendTaskFailureOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class Members64(BaseModel):
    taskToken: TaskToken


class SendTaskHeartbeatInput(BaseModel):
    type: str
    required: List[str]
    members: Members64


class SendTaskHeartbeatOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class Members65(BaseModel):
    taskToken: TaskToken
    output: Output26


class SendTaskSuccessInput(BaseModel):
    type: str
    required: List[str]
    members: Members65


class SendTaskSuccessOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class SensitiveCause(BaseModel):
    type: str
    max: int
    min: int
    sensitive: bool


class SensitiveData(BaseModel):
    type: str
    max: int
    sensitive: bool


class SensitiveDataJobInput(BaseModel):
    type: str
    max: int
    sensitive: bool


class SensitiveError(BaseModel):
    type: str
    max: int
    min: int
    sensitive: bool


class Name10(BaseModel):
    shape: str
    documentation: str


class Members66(BaseModel):
    stateMachineArn: StateMachineArn
    name: Name10
    input: Input26
    traceHeader: TraceHeader


class StartExecutionInput(BaseModel):
    type: str
    required: List[str]
    members: Members66


class Members67(BaseModel):
    executionArn: ExecutionArn
    startDate: StartDate


class StartExecutionOutput(BaseModel):
    type: str
    required: List[str]
    members: Members67


class Members68(BaseModel):
    stateMachineArn: StateMachineArn
    name: Name10
    input: Input26
    traceHeader: TraceHeader


class StartSyncExecutionInput(BaseModel):
    type: str
    required: List[str]
    members: Members68


class InputDetails4(BaseModel):
    shape: str


class OutputDetails4(BaseModel):
    shape: str


class BillingDetails1(BaseModel):
    shape: str
    documentation: str


class Members69(BaseModel):
    executionArn: ExecutionArn
    stateMachineArn: StateMachineArn
    name: Name10
    startDate: StartDate
    stopDate: StopDate
    status: Status
    error: Error26
    cause: Cause
    input: Input26
    inputDetails: InputDetails4
    output: Output26
    outputDetails: OutputDetails4
    traceHeader: TraceHeader
    billingDetails: BillingDetails1


class StartSyncExecutionOutput(BaseModel):
    type: str
    required: List[str]
    members: Members69


class InputDetails5(BaseModel):
    shape: str
    documentation: str


class Members70(BaseModel):
    name: Name10
    input: Input26
    inputDetails: InputDetails5


class StateEnteredEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members70
    documentation: str


class OutputDetails5(BaseModel):
    shape: str
    documentation: str


class Members71(BaseModel):
    name: Name10
    output: Output26
    outputDetails: OutputDetails5


class StateExitedEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members71
    documentation: str


class StateMachineList(BaseModel):
    type: str
    member: Member


class Members72(BaseModel):
    stateMachineArn: StateMachineArn
    name: Name10
    type: Type
    creationDate: CreationDate


class StateMachineListItem(BaseModel):
    type: str
    required: List[str]
    members: Members72
    documentation: str


class StateMachineStatus(BaseModel):
    type: str
    enum: List[str]


class StateMachineType(BaseModel):
    type: str
    enum: List[str]


class Members73(BaseModel):
    executionArn: ExecutionArn
    error: Error26
    cause: Cause


class StopExecutionInput(BaseModel):
    type: str
    required: List[str]
    members: Members73


class Members74(BaseModel):
    stopDate: StopDate


class StopExecutionOutput(BaseModel):
    type: str
    required: List[str]
    members: Members74


class SyncExecutionStatus(BaseModel):
    type: str
    enum: List[str]


class Key(BaseModel):
    shape: str
    documentation: str


class Value(BaseModel):
    shape: str
    documentation: str


class Members75(BaseModel):
    key: Key
    value: Value


class Tag(BaseModel):
    type: str
    members: Members75
    documentation: str


class TagKey(BaseModel):
    type: str
    max: int
    min: int


class TagKeyList(BaseModel):
    type: str
    member: Member


class TagList(BaseModel):
    type: str
    member: Member


class Members76(BaseModel):
    resourceArn: ResourceArn
    tags: Tags


class TagResourceInput(BaseModel):
    type: str
    required: List[str]
    members: Members76


class TagResourceOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class TagValue(BaseModel):
    type: str
    max: int
    min: int


class Members77(BaseModel):
    roleArn: RoleArn


class TaskCredentials1(BaseModel):
    type: str
    members: Members77
    documentation: str


class ResourceType(BaseModel):
    shape: str
    documentation: str


class Members78(BaseModel):
    resourceType: ResourceType
    resource: Resource
    error: Error26
    cause: Cause


class TaskFailedEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members78
    documentation: str


class Region(BaseModel):
    shape: str
    documentation: str


class Parameters(BaseModel):
    shape: str
    documentation: str


class TaskCredentials2(BaseModel):
    shape: str
    documentation: str


class Members79(BaseModel):
    resourceType: ResourceType
    resource: Resource
    region: Region
    parameters: Parameters
    timeoutInSeconds: TimeoutInSeconds
    heartbeatInSeconds: HeartbeatInSeconds
    taskCredentials: TaskCredentials2


class TaskScheduledEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members79
    documentation: str


class Members80(BaseModel):
    resourceType: ResourceType
    resource: Resource
    error: Error26
    cause: Cause


class TaskStartFailedEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members80
    documentation: str


class Members81(BaseModel):
    resourceType: ResourceType
    resource: Resource


class TaskStartedEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members81
    documentation: str


class Members82(BaseModel):
    resourceType: ResourceType
    resource: Resource
    error: Error26
    cause: Cause


class TaskSubmitFailedEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members82
    documentation: str


class Members83(BaseModel):
    resourceType: ResourceType
    resource: Resource
    output: Output26
    outputDetails: OutputDetails5


class TaskSubmittedEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members83
    documentation: str


class Members84(BaseModel):
    resourceType: ResourceType
    resource: Resource
    output: Output26
    outputDetails: OutputDetails5


class TaskSucceededEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members84
    documentation: str


class Members85(BaseModel):
    resourceType: ResourceType
    resource: Resource
    error: Error26
    cause: Cause


class TaskTimedOutEventDetails1(BaseModel):
    type: str
    required: List[str]
    members: Members85
    documentation: str


class TaskToken4(BaseModel):
    type: str
    max: int
    min: int


class TimeoutInSeconds3(BaseModel):
    type: str


class Timestamp1(BaseModel):
    type: str


class ToleratedFailureCount1(BaseModel):
    type: str
    min: int


class ToleratedFailurePercentage1(BaseModel):
    type: str
    max: int
    min: int


class TraceHeader4(BaseModel):
    type: str
    max: int
    min: int
    pattern: str


class Enabled1(BaseModel):
    shape: str
    documentation: str


class Members86(BaseModel):
    enabled: Enabled1


class TracingConfiguration3(BaseModel):
    type: str
    members: Members86
    documentation: str


class UnsignedInteger(BaseModel):
    type: str
    min: int


class UnsignedLong(BaseModel):
    type: str
    min: int


class TagKeys(BaseModel):
    shape: str
    documentation: str


class Members87(BaseModel):
    resourceArn: ResourceArn
    tagKeys: TagKeys


class UntagResourceInput(BaseModel):
    type: str
    required: List[str]
    members: Members87


class UntagResourceOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class MaxConcurrency2(BaseModel):
    shape: str
    documentation: str
    box: bool


class ToleratedFailurePercentage2(BaseModel):
    shape: str
    documentation: str
    box: bool


class ToleratedFailureCount2(BaseModel):
    shape: str
    documentation: str
    box: bool


class Members88(BaseModel):
    mapRunArn: MapRunArn
    maxConcurrency: MaxConcurrency2
    toleratedFailurePercentage: ToleratedFailurePercentage2
    toleratedFailureCount: ToleratedFailureCount2


class UpdateMapRunInput(BaseModel):
    type: str
    required: List[str]
    members: Members88


class UpdateMapRunOutput(BaseModel):
    type: str
    members: Dict[str, Any]


class LoggingConfiguration4(BaseModel):
    shape: str
    documentation: str


class TracingConfiguration4(BaseModel):
    shape: str
    documentation: str


class Members89(BaseModel):
    stateMachineArn: StateMachineArn
    definition: Definition2
    roleArn: RoleArn
    loggingConfiguration: LoggingConfiguration4
    tracingConfiguration: TracingConfiguration4


class UpdateStateMachineInput(BaseModel):
    type: str
    required: List[str]
    members: Members89


class Members90(BaseModel):
    updateDate: UpdateDate


class UpdateStateMachineOutput(BaseModel):
    type: str
    required: List[str]
    members: Members90


class IncludedDetails(BaseModel):
    type: str


class Truncated1(BaseModel):
    type: str


class Shapes(BaseModel):
    ActivityFailedEventDetails: ActivityFailedEventDetails
    ActivityList: ActivityList
    ActivityListItem: ActivityListItem
    ActivityScheduleFailedEventDetails: ActivityScheduleFailedEventDetails
    ActivityScheduledEventDetails: ActivityScheduledEventDetails
    ActivityStartedEventDetails: ActivityStartedEventDetails
    ActivitySucceededEventDetails: ActivitySucceededEventDetails
    ActivityTimedOutEventDetails: ActivityTimedOutEventDetails
    Arn: Arn
    BilledDuration: BilledDuration
    BilledMemoryUsed: BilledMemoryUsed
    BillingDetails: BillingDetails
    CloudWatchEventsExecutionDataDetails: CloudWatchEventsExecutionDataDetails
    CloudWatchLogsLogGroup: CloudWatchLogsLogGroup
    ConnectorParameters: ConnectorParameters
    CreateActivityInput: CreateActivityInput
    CreateActivityOutput: CreateActivityOutput
    CreateStateMachineInput: CreateStateMachineInput
    CreateStateMachineOutput: CreateStateMachineOutput
    Definition: Definition1
    DeleteActivityInput: DeleteActivityInput
    DeleteActivityOutput: DeleteActivityOutput
    DeleteStateMachineInput: DeleteStateMachineInput
    DeleteStateMachineOutput: DeleteStateMachineOutput
    DescribeActivityInput: DescribeActivityInput
    DescribeActivityOutput: DescribeActivityOutput
    DescribeExecutionInput: DescribeExecutionInput
    DescribeExecutionOutput: DescribeExecutionOutput
    DescribeMapRunInput: DescribeMapRunInput
    DescribeMapRunOutput: DescribeMapRunOutput
    DescribeStateMachineForExecutionInput: DescribeStateMachineForExecutionInput
    DescribeStateMachineForExecutionOutput: DescribeStateMachineForExecutionOutput
    DescribeStateMachineInput: DescribeStateMachineInput
    DescribeStateMachineOutput: DescribeStateMachineOutput
    Enabled: Enabled
    EventId: EventId
    ExecutionAbortedEventDetails: ExecutionAbortedEventDetails
    ExecutionFailedEventDetails: ExecutionFailedEventDetails
    ExecutionList: ExecutionList
    ExecutionListItem: ExecutionListItem
    ExecutionStartedEventDetails: ExecutionStartedEventDetails
    ExecutionStatus: ExecutionStatus
    ExecutionSucceededEventDetails: ExecutionSucceededEventDetails
    ExecutionTimedOutEventDetails: ExecutionTimedOutEventDetails
    GetActivityTaskInput: GetActivityTaskInput
    GetActivityTaskOutput: GetActivityTaskOutput
    GetExecutionHistoryInput: GetExecutionHistoryInput
    GetExecutionHistoryOutput: GetExecutionHistoryOutput
    HistoryEvent: HistoryEvent
    HistoryEventExecutionDataDetails: HistoryEventExecutionDataDetails
    HistoryEventList: HistoryEventList
    HistoryEventType: HistoryEventType
    Identity: Identity
    IncludeExecutionData: IncludeExecutionData1
    IncludeExecutionDataGetExecutionHistory: IncludeExecutionDataGetExecutionHistory
    LambdaFunctionFailedEventDetails: LambdaFunctionFailedEventDetails1
    LambdaFunctionScheduleFailedEventDetails: LambdaFunctionScheduleFailedEventDetails1
    LambdaFunctionScheduledEventDetails: LambdaFunctionScheduledEventDetails1
    LambdaFunctionStartFailedEventDetails: LambdaFunctionStartFailedEventDetails1
    LambdaFunctionSucceededEventDetails: LambdaFunctionSucceededEventDetails1
    LambdaFunctionTimedOutEventDetails: LambdaFunctionTimedOutEventDetails1
    ListActivitiesInput: ListActivitiesInput
    ListActivitiesOutput: ListActivitiesOutput
    ListExecutionsInput: ListExecutionsInput
    ListExecutionsOutput: ListExecutionsOutput
    ListExecutionsPageToken: ListExecutionsPageToken
    ListMapRunsInput: ListMapRunsInput
    ListMapRunsOutput: ListMapRunsOutput
    ListStateMachinesInput: ListStateMachinesInput
    ListStateMachinesOutput: ListStateMachinesOutput
    ListTagsForResourceInput: ListTagsForResourceInput
    ListTagsForResourceOutput: ListTagsForResourceOutput
    LogDestination: LogDestination
    LogDestinationList: LogDestinationList
    LogLevel: LogLevel
    LoggingConfiguration: LoggingConfiguration3
    LongArn: LongArn
    MapIterationEventDetails: MapIterationEventDetails
    MapRunExecutionCounts: MapRunExecutionCounts
    MapRunFailedEventDetails: MapRunFailedEventDetails1
    MapRunItemCounts: MapRunItemCounts
    MapRunLabel: MapRunLabel
    MapRunList: MapRunList
    MapRunListItem: MapRunListItem
    MapRunStartedEventDetails: MapRunStartedEventDetails1
    MapRunStatus: MapRunStatus
    MapStateStartedEventDetails: MapStateStartedEventDetails1
    MaxConcurrency: MaxConcurrency1
    Name: Name9
    PageSize: PageSize
    PageToken: PageToken
    ReverseOrder: ReverseOrder1
    SendTaskFailureInput: SendTaskFailureInput
    SendTaskFailureOutput: SendTaskFailureOutput
    SendTaskHeartbeatInput: SendTaskHeartbeatInput
    SendTaskHeartbeatOutput: SendTaskHeartbeatOutput
    SendTaskSuccessInput: SendTaskSuccessInput
    SendTaskSuccessOutput: SendTaskSuccessOutput
    SensitiveCause: SensitiveCause
    SensitiveData: SensitiveData
    SensitiveDataJobInput: SensitiveDataJobInput
    SensitiveError: SensitiveError
    StartExecutionInput: StartExecutionInput
    StartExecutionOutput: StartExecutionOutput
    StartSyncExecutionInput: StartSyncExecutionInput
    StartSyncExecutionOutput: StartSyncExecutionOutput
    StateEnteredEventDetails: StateEnteredEventDetails1
    StateExitedEventDetails: StateExitedEventDetails1
    StateMachineList: StateMachineList
    StateMachineListItem: StateMachineListItem
    StateMachineStatus: StateMachineStatus
    StateMachineType: StateMachineType
    StopExecutionInput: StopExecutionInput
    StopExecutionOutput: StopExecutionOutput
    SyncExecutionStatus: SyncExecutionStatus
    Tag: Tag
    TagKey: TagKey
    TagKeyList: TagKeyList
    TagList: TagList
    TagResourceInput: TagResourceInput
    TagResourceOutput: TagResourceOutput
    TagValue: TagValue
    TaskCredentials: TaskCredentials1
    TaskFailedEventDetails: TaskFailedEventDetails1
    TaskScheduledEventDetails: TaskScheduledEventDetails1
    TaskStartFailedEventDetails: TaskStartFailedEventDetails1
    TaskStartedEventDetails: TaskStartedEventDetails1
    TaskSubmitFailedEventDetails: TaskSubmitFailedEventDetails1
    TaskSubmittedEventDetails: TaskSubmittedEventDetails1
    TaskSucceededEventDetails: TaskSucceededEventDetails1
    TaskTimedOutEventDetails: TaskTimedOutEventDetails1
    TaskToken: TaskToken4
    TimeoutInSeconds: TimeoutInSeconds3
    Timestamp: Timestamp1
    ToleratedFailureCount: ToleratedFailureCount1
    ToleratedFailurePercentage: ToleratedFailurePercentage1
    TraceHeader: TraceHeader4
    TracingConfiguration: TracingConfiguration3
    UnsignedInteger: UnsignedInteger
    UnsignedLong: UnsignedLong
    UntagResourceInput: UntagResourceInput
    UntagResourceOutput: UntagResourceOutput
    UpdateMapRunInput: UpdateMapRunInput
    UpdateMapRunOutput: UpdateMapRunOutput
    UpdateStateMachineInput: UpdateStateMachineInput
    UpdateStateMachineOutput: UpdateStateMachineOutput
    includedDetails: IncludedDetails
    truncated: Truncated1


class Model(BaseModel):
    version: str
    metadata: Metadata
    operations: Operations
    shapes: Shapes
    documentation: str
